==> pythonnet-2.4.0rc2.tar.gz: pythonnet-2.4.0rc2/src/embed_tests/TestPyWith.cs <==
using System;
using NUnit.Framework;
using Python.Runtime;

namespace Python.EmbeddingTest
{
    public class TestPyWith
    {
        [OneTimeSetUp]
        public void SetUp()
        {
            PythonEngine.Initialize();
        }

        [OneTimeTearDown]
        public void Dispose()
        {
            PythonEngine.Shutdown();
        }

        /// <summary>
        /// Test that exception is raised in context manager that ignores it.
        /// </summary>
        [Test]
        public void TestWithPositive()
        {
            var locals = new PyDict();
            
            PythonEngine.Exec(@"
class CmTest:
    def __enter__(self):
        print('Enter')
        return self
    def __exit__(self, t, v, tb):
        # Exception not handled, return will be False
        print('Exit')
    def fail(self):
        return 5 / 0

a = CmTest()
", null, locals.Handle);

            var a = locals.GetItem("a");

            try
            {
                Py.With(a, cmTest =>
                {
                    cmTest.fail();
                });
            }
            catch (PythonException e)
            {
                Assert.IsTrue(e.Message.Contains("ZeroDivisionError"));
            }
        }


        /// <summary>
        /// Test that exception is not raised in context manager that handles it
        /// </summary>
        [Test]
        public void TestWithNegative()
        {
            var locals = new PyDict();

            PythonEngine.Exec(@"
class CmTest:
    def __enter__(self):
        print('Enter')
        return self
    def __exit__(self, t, v, tb):
        # Signal exception is handled by returning true
        return True
    def fail(self):
        return 5 / 0

a = CmTest()
", null, locals.Handle);

            var a = locals.GetItem("a");
            Py.With(a, cmTest =>
            {
                cmTest.fail();
            });
        }
    }
}

==> pythonnet-3.0.1.tar.gz: pythonnet-3.0.1/src/embed_tests/TestPyWith.cs <==
using System;
using NUnit.Framework;
using Python.Runtime;

namespace Python.EmbeddingTest
{
    public class TestPyWith
    {
        [OneTimeSetUp]
        public void SetUp()
        {
            PythonEngine.Initialize();
        }

        [OneTimeTearDown]
        public void Dispose()
        {
            PythonEngine.Shutdown();
        }

        /// <summary>
        /// Test that exception is raised in context manager that ignores it.
        /// </summary>
        [Test]
        public void TestWithPositive()
        {
            var locals = new PyDict();

            PythonEngine.Exec(@"
class CmTest:
    def __enter__(self):
        return self
    def __exit__(self, t, v, tb):
        # Exception not handled, return will be False
        pass
    def fail(self):
        return 5 / 0

a = CmTest()
", null, locals);

            var a = locals.GetItem("a");

            try
            {
                Py.With(a, cmTest =>
                {
                    cmTest.fail();
                });
            }
            catch (PythonException e)
            {
                TestContext.Out.WriteLine(e.Message);
                Assert.IsTrue(e.Type.Name == "ZeroDivisionError");
            }
        }


        /// <summary>
        /// Test that exception is not raised in context manager that handles it
        /// </summary>
        [Test]
        public void TestWithNegative()
        {
            var locals = new PyDict();

            PythonEngine.Exec(@"
class CmTest:
    def __enter__(self):
        print('Enter')
        return self
    def __exit__(self, t, v, tb):
        # Signal exception is handled by returning true
        return True
    def fail(self):
        return 5 / 0

a = CmTest()
", null, locals);

            var a = locals.GetItem("a");
            Py.With(a, cmTest =>
            {
                cmTest.fail();
            });
        }
    }
}
